<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Category;
use App\Models\Customer;
use App\Models\Order;
use App\Models\Product;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class LoginController extends Controller
{
    public function index()
    {
        return view('admin.auth.login');
    }

    public function authenticate(Request $request)
    {
        $attempt = Auth::attempt(['email' => $request->email, 'password' => $request->password]);
        if ($attempt) {
            return redirect()
                ->route('admin.dashboard');
        }
        return redirect()
            ->back()
            ->with('danger', 'Invalid Credentials');
    }


    public function logout()
    {
        Auth::logout();
        return redirect('admin/login');
    }
    public function dashboard(Request $request)
    {
        $from_date = $request->from_date;
        $to_date = $request->to_date;
        if ($from_date && $to_date) {
            $products = Product::whereBetween('created_at', [$from_date, $to_date])->count();
            $categories = Category::whereBetween('created_at', [$from_date, $to_date])->count();
            $customers = Customer::whereBetween('created_at', [$from_date, $to_date])->count();
            $orders = Order::whereBetween('created_at', [$from_date, $to_date])->count();
        } else {
            $products = Product::count();
            $categories = Category::count();
            $customers = Customer::count();
            $orders = Order::count();
        }
        return view('admin.dashboard', compact('products', 'categories', 'customers', 'orders'));
    }
}
