<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Category;
use App\Models\Customer;
use App\Models\Order;
use App\Models\Product;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use App\Exports\OrderExport;
use App\Mail\DiscountUpdated;
use App\Models\OrderItem;
use Illuminate\Support\Facades\Mail;
use Maatwebsite\Excel\Facades\Excel;

class OrderController extends Controller
{
    public function model()
    {
        return new Order;
    }
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $searchColumns = ['id', 'company_name', 'customer_name'];
        $search = request()->search;
        $order = request()->orderedColumn;
        $orderBy = request()->orderBy;
        $paginate = request()->paginate;

        $query = $this->model()->newQuery();

        if ($search != '') {
            $query->where(function ($q) use ($search, $searchColumns) {
                foreach ($searchColumns as $key => $value) {
                    ($key == 0) ? $q->where($value, 'LIKE', '%' . $search . '%') : $q->orWhere($value, 'LIKE', '%' . $search . '%');
                }
            });
        }

        ($order == '') ? $query->orderByDesc('id') : $query->orderBy($order, $orderBy);

        $query->with(['items.product.images']);

        $orders = $paginate ? $query->paginate($paginate)->appends(request()->query()) : $query->paginate(10)->appends(request()->query());

        return view('admin.order.index', compact('orders'));
    }


    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $category = request()->category;
        $customers = Customer::all();
        $categories = Category::where('status', 1)->get();
        if ($category) {
            $category = Category::find($category);
            $products = $category->products;
        } else {
            $products = $categories[0]->products;
        }
        $items = [];
        return view('admin.order.create', compact('customers', 'categories', 'products', 'items'));
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        // dd($request->all());
        DB::beginTransaction();
        try {
            $customer = Customer::find($request->customer_id);
            //create an order
            $order = $this->model()->create([
                'customer_id' => $customer->id,
                'order_id' => 1,
                'company_name' => $customer->company_name,
                'customer_name' => $customer->contact_person,
                'total_product' => $request->no_of_products,
                'total_amount' => $request->total_amount,
                'tax' => $request->tax ?? 0,
                'grand_total' => $request->grand_total,
            ]);

            //create an order items 
            foreach ($request->product_id as $key => $product_id) {
                $product = Product::find($product_id);
                $order->items()->create([
                    'product_id' => $product_id,
                    'name' => $product->name,
                    'quantity' => $request->quantity[$key],
                    'sku' => $product->sku,
                    'price' => $request->selling_price[$key],
                    'total_amount' => $request->tot_price[$key],
                ]);
            }
            DB::commit();
            return redirect()->route('admin.orders')->with('message', 'Your Order Successful');
        } catch (Exception $ex) {
            DB::rollBack();
            dd($ex);
        }
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        $order = $this->model()->find($id);
        return view('admin.order.details', compact('order'));
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        //
    }

    public function export()
    {
        return Excel::download(new OrderExport, 'Orders.xlsx');
    }

    public function updateDiscount(Request $request, $orderId)
    {
        $discounts = $request->input('discounts');
        $order = Order::findOrFail($orderId);

        foreach ($discounts as $itemId => $discount) {
            $orderItem = OrderItem::where('order_id', $orderId)->where('id', $itemId)->firstOrFail();

            $quantity = $orderItem->quantity;
            $totalAmount = $discount * $quantity;

            $orderItem->discount = $discount;
            $orderItem->total_amount = $totalAmount;
            $orderItem->save();
        }

        $order->grand_total = $order->items->sum('total_amount');
        $order->total_amount = $order->items->sum('total_amount');
        $order->save();
        $this->sendDiscountUpdateEmail($order, $discounts);

        return response()->json(['success' => true]);
    }
    protected function sendDiscountUpdateEmail($order, $discounts)
    {
        try {
            Mail::to($order->customer->email)->send(new DiscountUpdated($order, $discounts));
        } catch (\Exception $e) {
            return response($e);
        }
    }
}
