<?php

namespace App\Http\Controllers\frontend;

use App\Http\Controllers\Controller;
use App\Models\Brands;
use App\Models\Category;
use App\Models\Page;
use App\Models\Product;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Session;
use Carbon\Carbon;


class ShopController extends Controller
{
    public function model()
    {
        return new Product;
    }
    public function index()
    {
        $top_categories = Category::tree()
            ->with('image', 'products')
            ->whereNull('parent_id')
            ->orderBy('position', 'asc')
            ->where('status', true)
            ->take(6)
            ->get();
        $brands = Brands::where('status', 1)->latest()->get();
        return view('welcome', compact('top_categories', 'brands'));
    }

    public function productlist(Request $request)
    {
        $sale = $request->sale;

        $top_categories = Category::tree()
            ->with('image', 'products')
            ->whereNull('parent_id')
            ->where('status', true)
            ->orderBy('position', 'asc')
            ->get();

        $query = Product::with('images', 'brand_name')
            ->where('status', true);

        if ($request->has('brand') && !empty($request->brand)) {
            $brands = explode(',', $request->brand);
            $query->whereIn('brand', $brands);
        }

        if ($request->has('price') && !empty($request->price)) {
            $priceRange = explode('-', $request->price);
            if (count($priceRange) == 2) {
                $query->whereBetween('price', [(float)$priceRange[0], (float)$priceRange[1]]);
            }
        }
        if ($sale) {
            $today = Carbon::today();
        }

        $products = $query->get();

        $brands = Brands::where('status', true)
            ->orderBy('position', 'asc')
            ->get();

        return view('frontend.pages.productlists', compact('top_categories', 'products', 'brands'));
    }


    public function productByCategory(Request $request, $slug)
    {

        $brands = Brands::where('status', 1)->latest()->get();
        $sort = $request->sort;
        $order = $request->order;
        $paginate = $request->paginate;
        $is_new = $request->is_new;
        $all = $request->all;
        $is_best_seller = $request->is_best_seller;
        $brand = $request->brand;
        $price = $request->price;
        $sale = $request->sale;
        $sku = $request->sku;
        $sub_categories = collect();
        $query = Product::query();
        $category = Category::where('slug', $slug)->first();

        $top_categories = Category::tree()
            ->with('image', 'products')
            ->whereNull('parent_id')
            ->orderBy('position', 'asc')
            ->where('status', true)
            ->get();

        if (!is_null($category)) {
            $category_children = $category->child()->pluck('id')->toArray();
            $categories_id = array_merge([$category->id], $category_children);
            $query->whereHas('categories', function ($query) use ($categories_id) {
                $query->whereIn('category_id', $categories_id);
            });
            $sub_categories = $category->descendants()->get();
        }
        if ($brand) {
            $brand = explode(',', $brand);
            $query->whereHas('brand_name', function ($query) use ($brand) {
                $query->whereIn('brand', $brand);
            });
        }
        if ($price) {
            $price = explode('-', $price);
            $query->whereBetween('price', $price);
        }
        if ($sale) {
            $today = Carbon::today();

            $query->where(function ($query) use ($today) {
                $query->whereNotNull('special_price_from')
                    ->where('special_price_from', '<=', $today);
            })->where(function ($query) use ($today) {
                $query->whereNotNull('special_price_to')
                    ->where('special_price_to', '>=', $today);
            });
        }
        if ($is_new) {
            $query->where('is_new', $is_new);
        }
        if ($is_best_seller) {
            $query->where('is_best_seller', $is_best_seller);
        }
        if ($slug == 'categorysearch') {
            $all = 'all';
        }
        ($sort == '') ? $query->orderByDesc('id') : $query->orderBy($sort, $order);
        $query->where('status', true);
        $products = $paginate ? $query->paginate($paginate)->appends(request()->query()) : $query->paginate(100)->appends(request()->query());
        if ($category || $brand || $is_new || $is_best_seller || $all || $sale) {
            return view('frontend.pages.productsbycategory', compact('products', 'sub_categories', 'category', 'top_categories', 'brands'));
        } else {
            if ($sku) {
                $product = Product::where('id', $slug)->where('sku', $sku)->first();
            } else {
                $product = Product::where('id', $slug)->first();
            }
            if ($product) {
                $category = $product->categories()->first();
                if ($category) {
                    $category = $category->category;
                } else {
                    $category = Category::latest()->first();
                }
                $sub_categories = $category->descendants()->pluck('id')->toArray();
                $parent_categories = $category->ancestors()->pluck('id')->toArray();
                $relatedProducts = $this->getProductsByCategory(array_merge([$category->id], $sub_categories, $parent_categories));
                $recentIds = Session::get('recents', []);
                array_push($recentIds, $product->id);
                Session::put('recents', $recentIds);
                $recentViewed = Product::whereIn('id', $recentIds)->where('id', '<>', $product->id)->get();
                return view('frontend.pages.productdetail', compact('product', 'relatedProducts', 'recentViewed'));
            } else {
                abort(404, 'Page not found');
            }
        }
    }
    public function activeProducts()
    {
        return $this->model()->with('images', 'inventory')
            ->where('status', true);
    }
    public function getProductsByCategory($categories = [])
    {
        $products = $this->activeProducts()
            ->whereHas('categories', function ($subquery) use ($categories) {
                $subquery->whereIn('category_id', $categories);
            })
            ->paginate(25);

        return $products;
    }

    public function getProductsBy($type, $value, $limit = 0)
    {
        return $this->activeProducts()
            ->where($type, $value)
            ->take($limit)
            ->get();
    }

    public function pageDetails($page)
    {
        $pageDetails = Page::where('slug', $page)->first();
        if ($pageDetails) {
            return view('frontend.pages.page-view', compact('pageDetails'));
        } else {
            abort(404, 'Page not found');
        }
    }
}
