<?php

namespace App\Http\Controllers\frontend;

use App\Mail\AccountActivatedMail;
use Illuminate\Support\Facades\Mail;


use App\Http\Controllers\Controller;
use App\Models\Cart;
use App\Models\Customer;
use App\Models\Order;
use Exception;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Auth;
use Illuminate\Http\Request;
use Illuminate\Validation\ValidationException;



class UserController extends Controller
{

    public function model()
    {
        return new Customer;
    }
    public function register()
    {
        $lastCustomer = Customer::latest()->first();

        if ($lastCustomer) {
            $lastCustomerId = $lastCustomer->customer_id;
            $lastCustomerNumber = (int)substr($lastCustomerId, 5);
            $newCustomerNumber = $lastCustomerNumber + 1;
            $newCustomerId = 'VERSC' . str_pad($newCustomerNumber, 4, '0', STR_PAD_LEFT);
        } else {
            $newCustomerId = 'VERSC0001';
        }
        return view('frontend.auth.register', compact('newCustomerId'));
    }

    public function login()
    {
        return view('frontend.auth.login');
    }

    public function store(Request $request)
    {
        $request->validate([
            'company_name' => 'required',
            'contact_person' => 'required',
            'phone' => 'required',
            'email' => 'required|unique:customers',
            'password' => 'required',
            'conf_password' => 'required|same:password',
        ]);
        DB::beginTransaction();
        try {
            $data = $request->all();
            $data['password'] = Hash::make($request->password);
            // dd($data);
            $this->model()->create($data);
            DB::commit();
        } catch (Exception $e) {
            DB::rollBack();
            dd($e);
        }
        return redirect()->route('customer.login')->with('message', 'Request sent wait for the approval !!');
    }
    public function authenticate(Request $request)
    {
        $request->validate([
        
            'password' => 'required'
        ]);

        $cust = Customer::where('email', $request->email)
        ->orWhere('customer_id', $request->email)
        ->first();
    
        if (is_null($cust) || $cust->password == '') {
            return back()->with('danger', 'Account Not Found');
        }

        if ($cust->status != true) {
            return back()->with('danger', 'Your account is inactive. Please contact support.');
        }

        $attempt = Auth::guard('customer')->attempt(['email' => $request->email, 'password' => $request->password]);

        if ($attempt) {
            $customer = Auth::guard('customer')->user();

            $this->updateCart();

            return redirect()->route('customer.profile');
        } else {
            $attempt = Auth::guard('customer')->attempt(['customer_id' => $request->email, 'password' => $request->password]);
            if ($attempt) {
                $customer = Auth::guard('customer')->user();

                $this->updateCart();

                return redirect()->route('customer.profile');
            }
        }

        return back()->with('danger', 'Invalid credentials.');
    }



    public function updateCart()
    {
        $customer = auth('customer')->user();
        $cart_id = session('cart_id');

        if (!is_null($cart_id)) {

            $cart = Cart::find($cart_id);
            // dd($cart,$customer->cart);
            //check if customer has already cart
            if ($customer->cart) {
                //load session cart and add it to customer cart id
                foreach ($cart->items as $item) {

                    app(CartController::class)->cartItemCreate($customer->cart, $item->product_id, $item->quantity);

                    //delete cart item of session
                    app(CartController::class)->destroy($item->id);
                }
                //update cart total 
                $customer->cart()->update([
                    'items_qty'       => $customer->cart->items_qty + $cart->items_qty,
                    'total_amount'    => $customer->cart->total_amount + $cart->total_amount,
                    'tax_total'       => $customer->cart->tax_total + $cart->tax_total,
                    'discount_amount' => $customer->cart->discount_amount + $cart->discount_amount,
                    'grand_total'     => $customer->cart->grand_total + $cart->grand_total,
                    'coupon_code'     => $cart->coupon_code,
                ]);

                //delete session cart
                $cart->delete();
            } else {
                $cart->update([
                    'customer_id' => $customer->id,
                    'first_name' => $customer->name,
                    'last_name' => $customer->name,
                    'email' => $customer->email,
                    'phone' => $customer->phone,
                ]);
            }

            app(CartController::class)->calculateTotal($cart_id);

            session()->forget('cart_id');
        }
    }
    public function profile()
    {
        $customer = auth('customer')->user();
        return view('frontend.customer.profile', compact('customer'));
    }
    public function logout()
    {
        Auth::guard('customer')->logout();
        return redirect('/');
    }
    public function update(Request $request)
    {
        $request->validate([
            'company_name' => 'required',
            'contact_person' => 'required',
            'phone' => 'required',
            'email' => 'required',
        ]);
        $customer = Auth::guard('customer')->user();
        $customer->update([
            'company_name' => $request->company_name,
            'contact_person' => $request->contact_person,
            'email' => $request->email,
            'phone' => $request->phone,
        ]);
        return back()->with('message', 'Profile updated successfully');
    }
    public function reset(Request $request)
    {
        $request->validate([
            'new_password' => 'required',
            'conf_password' => 'required|same:new_password',
        ], ['conf_password.same' => 'Password and confirm password should same']);
        $customer = auth('customer')->user();
        $customer->update([
            'password' => Hash::make($request->new_password)
        ]);
        return back()->with('message', 'Password reseted successfully');
    }
    public function orders()
    {
        $customer = auth('customer')->user();
        return view('frontend.customer.orders', compact('customer'));
    }
    public function orderDetails($id)
    {
        $order = Order::find($id);
        return view('frontend.customer.order-details', compact('order'));
    }

    public function updateStatus(Request $request, $customerId)
    {
        $customer = Customer::findOrFail($customerId);

        if ($customer->status == false && $request->status == true) {
            $customer->status = true;
            $customer->save();

            Mail::to($customer->email)->send(new AccountActivatedMail($customer));

            return response()->json([
                'message' => 'Customer account activated and activation email sent.'
            ]);
        }

        $customer->status = $request->status;
        $customer->save();

        return response()->json([
            'message' => 'Customer status updated.'
        ]);
    }
}
