<?php

namespace App\Imports;

use App\Models\Customer;
use Illuminate\Support\Facades\Hash;
use Maatwebsite\Excel\Concerns\SkipsFailures;
use Maatwebsite\Excel\Concerns\SkipsOnFailure;
use Maatwebsite\Excel\Concerns\ToModel;
use Maatwebsite\Excel\Concerns\WithBatchInserts;
use Maatwebsite\Excel\Concerns\WithChunkReading;
use Maatwebsite\Excel\Concerns\WithHeadingRow;
use Maatwebsite\Excel\Concerns\WithUpserts;
use Illuminate\Support\Str;
use Maatwebsite\Excel\Concerns\SkipsEmptyRows;

use Maatwebsite\Excel\Concerns\WithValidation;

class CustomerImport implements SkipsEmptyRows, ToModel, WithHeadingRow, SkipsOnFailure, WithValidation, WithBatchInserts, WithChunkReading, WithUpserts
{
    use SkipsFailures;
    /**
     * @param array $row
     *
     * @return \Illuminate\Database\Eloquent\Model|null
     */
    private $sku;
    public function model(array $row)
    {
        $lastCustomer = Customer::orderBy('customer_id', 'desc')->first();

        if ($lastCustomer) {
            $lastCustomerId = $lastCustomer->customer_id;
            $lastCustomerNumber = (int)substr($lastCustomerId, 5);
            $newCustomerNumber = $lastCustomerNumber + 1;
            $newCustomerId = 'VERSC' . str_pad($newCustomerNumber, 4, '0', STR_PAD_LEFT);
        } else {
            $newCustomerId = 'VERSC0001';
        }
        $customer = Customer::create([
            'customer_id' => $newCustomerId,
            'company_name' => $row['company_name'],
            'contact_person' => $row['contact_person'],
            'phone' => $row['phone'],
            'mobile' => $row['mobile'],
            'email' => $row['email'],
            'billing_address' => $row['billing_address'],
            'shipping_address' => $row['shipping_address'],
            'password' => Hash::make($row['password']),
        ]);
        return $customer;
    }

    public function rules(): array
    {
        return [
            'contact_person' => 'required',
            'email' => 'required|unique:customers',
        ];
    }
    public function batchSize(): int
    {
        return 50;
    }

    public function chunkSize(): int
    {
        return 50;
    }
    public function uniqueBy()
    {
        return 'customer_id';
    }
}
